@@ -169,4 +169,18 @@ pub fn test_exec() {
         },
         Err(err) => panic!("{}", err.to_string())
     };
+
+    match unsafe { execsvc.execute(&mut Exec::new(&vec![
+        OP_JUMP, 4,
+        OP_RETURN, 30,
+        OP_JUMP, 2
+    ]), &vec![]) } {
+        Ok(ok) => {
+            match ok {
+                Ok(ok) => assert_eq!(ok, 30),
+                Err(_) => panic!("expected Ok")
+            }
+        },
+        Err(err) => panic!("{}", err.to_string())
+    };
 }
